@@ -2,7 +2,7 @@
  *
  * Translate algorithm identifiers (or names) to algorithm objects.
  *
- * $Id: algorithms.h,v 1.2 1999/10/11 19:50:42 nisse Exp $ */
+ * $Id: algorithms.h,v 1.3 1999/11/07 20:53:03 nisse Exp $ */
 
 #ifndef LSH_ALGORITHMS_H_INCLUDED
 #define LSH_ALGORITHMS_H_INCLUDED
@@ -26,9 +26,10 @@
 */
 
 struct alist *many_algorithms(unsigned count, ...);
-int lookup_crypto(struct alist *algorithms, char *name);
-int lookup_mac(struct alist *algorithms, char *name);
-int lookup_compression(struct alist *algorithms, char *name);
+int lookup_crypto(struct alist *algorithms, const char *name);
+int lookup_mac(struct alist *algorithms, const char *name);
+int lookup_compression(struct alist *algorithms, const char *name);
+int lookup_hash(struct alist *algorithms, const char *name, int none_is_valid);
 
 struct int_list *default_crypto_algorithms(void);
 struct int_list *default_mac_algorithms(void);
