@@ -2,7 +2,7 @@
  *
  * Client specific key exchange handling
  *
- * $Id: client_keyexchange.h,v 1.13 1999/09/06 22:13:50 nisse Exp $ */
+ * $Id: client_keyexchange.h,v 1.14 1999/12/07 22:35:07 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -31,8 +31,8 @@
 #include "publickey_crypto.h"
 
 struct keyexchange_algorithm *
-make_dh_client(struct diffie_hellman_method *dh,
-	       struct alist *verifiers);
+make_dh_client(struct diffie_hellman_method *dh);
+     /* struct alist *verifiers); */
 
 struct install_keys *make_client_install_keys(struct object_list *algorithms);
 
