@@ -1,6 +1,6 @@
 /* exception.c
  *
- * $Id: exception.c,v 1.11 1999/11/07 21:01:16 nisse Exp $ */
+ * $Id: exception.c,v 1.12 1999/12/12 19:33:59 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -40,18 +40,7 @@ static void
 do_default_handler(struct exception_handler *ignored UNUSED,
 		   const struct exception *e)
 {
-#if 0
-  if (e->type & EXC_IO)
-    {
-      CAST_SUBTYPE(io_exception, io, e);
-      werror("i/o error (errno = %i): %z\n", io->error, e->msg);
-      
-      if (io->fd)
-	kill_fd(io->fd);
-    }
-  else
-#endif
-    fatal("Unhandled exception of type 0x%xi: %z\n", e->type, e->msg);
+  fatal("Unhandled exception of type 0x%xi: %z\n", e->type, e->msg);
 }
 
 struct exception_handler default_exception_handler =
