@@ -1,6 +1,6 @@
 /* lsh.h
  *
- * $Id: lsh.h,v 1.10 1999/11/25 22:36:12 nisse Exp $ */
+ * $Id: lsh.h,v 1.11 1999/12/12 19:34:05 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -98,20 +98,6 @@ struct lsh_string
   UINT8 data[1];
 };
 
-#if 0
-/* A closed function with no arguments */
-struct callback;
-typedef int (*callback_f)(struct callback *closure);
-struct callback
-{
-  struct lsh_object header;
-  
-  int (*f)(struct callback *closure);
-};
-
-#define CALLBACK(c) ((c)->f(c))
-#endif
-
 
 /* Forward declarations of various structures */
 
