@@ -2,7 +2,7 @@
  *
  * A read handler for application data.
  *
- * $Id: read_data.h,v 1.10 1999/09/07 17:06:14 nisse Exp $ */
+ * $Id: read_data.h,v 1.11 1999/10/11 21:02:36 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -31,8 +31,11 @@
 struct io_read_callback *make_read_data(struct ssh_channel *channel,
 					struct abstract_write *write);
 
+#if 0
 struct exception_handler *
 make_exc_read_eof_channel_handler(struct ssh_channel *channel,
-				  struct exception_handler *e);
+				  struct exception_handler *e,
+				  const char *context);
+#endif
 
 #endif /* LSH_READ_DATA_H_INCLUDED */
