@@ -1,6 +1,6 @@
 /* server_keyexchange.c
  *
- * $Id: server_keyexchange.c,v 1.35 1999/12/07 22:15:09 nisse Exp $ */
+ * $Id: server_keyexchange.c,v 1.36 1999/12/12 19:34:07 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -146,9 +146,6 @@ do_init_server_dh(struct keyexchange_algorithm *c,
   NEW(dh_server, dh);
 
   CHECK_TYPE(ssh_connection, connection);
-#if 0
-  CHECK_SUBTYPE(signature_algorithm, ignored);
-#endif
   
   /* FIXME: No spki-style signatures for host keys. */
   assert(hostkey_algorithm_atom == ATOM_SSH_DSS);
