@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.21 1999/12/12 19:34:08 nisse Exp $
+ * $Id: server_session.c,v 1.22 1999/12/31 01:08:31 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -1000,7 +1000,7 @@ do_alloc_pty(struct channel_request *c UNUSED,
       KILL(pty);
     }
 
-  verbose(" failed.\n");
+  verbose("Pty allocation failed.\n");
   lsh_string_free(term);
 
   if (want_reply)
